close all
addpath(genpath(pwd));
load data_paper.mat
load ICs.mat
modelpath=strcat(cd,'/models/');

model   =SBmodel(strcat(modelpath,'/Model_mdck_sus.txt'));
flag=0;
try % compile the model
    SBPDmakeMEXmodel(model,'model');
    flag=1;
catch errmsg
    fprintf('\n Mex compilation failed... needs compiler gcc in linux, or MinGW-64 on windows! Using SBsimulate instead \n')
    fprintf('Please wait (non mex simulations may take a while, or it may not work at all)... \n');
end

IC1=ICs(1,:);
IC2=ICs(2,:);
t1=[0:60:data_paper.Cult1.time(end) data_paper.Cult1.time(end)];t1=unique(t1);
t2=[0:60:data_paper.Cult2.time(end) data_paper.Cult2.time(end)];t2=unique(t2);
dc=[19.5849  19.5849 ];
dm=[9.75520  9.95520];

if flag  % simulate mex
    % sim preculture
    results.precult=SBPDsimulate('model',[0 5040],IC1,{ 'd_c','d_m','Elevel' },[dc(1) dm(1) 1],[]);
    % update Initial Condition for Cult1
    IC1(12:34)=results.precult.statevalues(end,12:34);
    % sim Cult1
    results.Cult1=SBPDsimulate('model',t1,IC1,{ 'd_c','d_m','Elevel' },[dc(1) dm(1) 1],[]);
    
    % update Initial Condition for Cult2
    IC2(12:34)=results.precult.statevalues(end,12:34);
    % sim Cult2 before infection
    results.Cult2=SBPDsimulate('model',[t2(1:49) 48.1667*60],IC2,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1],[]);
    % introduce the virus Cult 2
    results.Cult2.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    temp=SBPDsimulate('model',[results.Cult2.time(end) t2(50:end)],results.Cult2.statevalues(end,:),{ 'd_c','d_m','Elevel' 'kbinf' },[dc(2) dm(2) 1 1],[]);
    % join before and after infection sim data
    results.Cult2.time=[results.Cult2.time(1:end-1) temp.time(2:end)];
    results.Cult2.statevalues=[results.Cult2.statevalues(1:end-1,:);temp.statevalues(2:end,:)*1];
    results.Cult2.variablevalues=[results.Cult2.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)*1];
else % simulate without mex
    % sim preculture
    model=SBparameters(model,{ 'd_c','d_m','Elevel' },[dc(1) dm(1) 1]); % update parameters values for d_c d_m and Elevel 
    results.precult=SBsimulate(model,'ode15s',[0 5040],IC1);
    % update Initial Condition for Cult1
    IC1(12:34)=results.precult.statevalues(end,12:34);
    % sim Cult1
    results.Cult1=SBsimulate(model,'ode15s',t1,IC1);
    
    % update Initial Condition for Cult2
    IC2(12:34)=results.precult.statevalues(end,12:34);
    % sim Cult2 before infection
    model=SBparameters(model,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1]);% update parameters values for d_c d_m and Elevel 
    results.Cult2=SBsimulate(model,'ode15s',[t2(1:49) 48.1667*60],IC2);
    % introduce the virus Cult 2
    results.Cult2.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    model=SBparameters(model,{ 'kbinf' },[1]);% update parameters values for kbinf
    temp=SBsimulate(model,'ode15s',[results.Cult2.time(end) t2(50:end)],results.Cult2.statevalues(end,:));
    % join before and after infection sim data
    results.Cult2.time=[results.Cult2.time(1:end-1) ;temp.time(2:end)];
    results.Cult2.statevalues=[results.Cult2.statevalues(1:end-1,:);temp.statevalues(2:end,:)];
    results.Cult2.variablevalues=[results.Cult2.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)];

end

%%%%% To plot a state just change the state='Glcx' string e.g. state='Glnx'
figure;
state='Glcx';
plot(results.Cult1.time/60,results.Cult1.statevalues(:,strcmp(results.Cult1.states,state)),'g--','LineWidth',2);
ylabel(state);xlabel('time (h)');set(gca,'FontSize',13,'Fontweight','Bold')

%%%%% To plot a variable just change the variable='r_LDH' string e.g. variable='r_MDH'
figure;
variable='r_LDH';plot(results.Cult1.time/60,results.Cult1.variablevalues(:,strcmp(results.Cult1.variables,variable)),'b','LineWidth',2);
ylabel(variable);xlabel('time (h)');set(gca,'FontSize',13,'Fontweight','Bold')

%%%% Auto plot, no standard deviations
figure;
states_model={'Glcx' 'Lacx'  'Glux' 'Pyrx' 'Glnx' 'NH4x' 'ATP'  'Cit'  'cAc' 'Isocit'  'Keto' 'SUC' 'Fum' 'Mal'  'G6P'  'F6P'  'F16P' 'G3P' 'PEP'  'R5P' 'UDPGlc'  };

for i=1:numel(states_model)
    subplot(5,5,i)
    id_model=strcmp(results.Cult1.states,states_model(i));
    id_data=strcmp(data_paper.Cult1.states,states_model(i));
    plot(data_paper.Cult1.time/60,data_paper.Cult1.values(:,id_data), 'go','LineWidth',2,'MarkerSize',10);hold on;
    plot(results.Cult1.time/60,results.Cult1.statevalues(:,id_model), 'g-','LineWidth',2,'MarkerSize',10)
    plot(data_paper.Cult2.time/60,data_paper.Cult2.values(:,id_data), 'ro','LineWidth',2,'MarkerSize',10);
    plot(results.Cult2.time/60,results.Cult2.statevalues(:,id_model), 'r-','LineWidth',2,'MarkerSize',10)
    ylabel(states_model(i));xlabel('time (h)');set(gca,'FontSize',13,'Fontweight','Bold')
    ylim([0 max([data_paper.Cult2.values(:,id_data)' data_paper.Cult1.values(:,id_data)'])*1.25]);
    set(gcf, 'Position', get(0, 'Screensize'));
    
end

%%%% Auto plot, no standard deviations
variable_model={'X_tot' 'VC'   'd'};
figure;
for i=1:numel(variable_model)
    subplot(1,3,i)
    id_model=strcmp(results.Cult1.variables,variable_model(i));
    id_data=strcmp(data_paper.Cult1.states,variable_model(i));
    if i==1
        plot(data_paper.Cult1.time/60,data_paper.Cult1.values(:,id_data)*1e6, 'go','LineWidth',2,'MarkerSize',10);hold on;
    else
        plot(data_paper.Cult1.time/60,data_paper.Cult1.values(:,id_data), 'go','LineWidth',2,'MarkerSize',10);hold on;
    end
    plot(results.Cult1.time/60,results.Cult1.variablevalues(:,id_model), 'g-','LineWidth',2)
    
    if i==1
        plot(data_paper.Cult2.time/60,data_paper.Cult2.values(:,id_data)*1e6, 'ro','LineWidth',2,'MarkerSize',10);
    else
        plot(data_paper.Cult2.time/60,data_paper.Cult2.values(:,id_data), 'ro','LineWidth',2,'MarkerSize',10);
    end
    plot(results.Cult2.time/60,results.Cult2.variablevalues(:,id_model), 'r-','LineWidth',2)
    if i==1
        ylabel('Viable cell concentration (Cells/mL)');
    elseif i==2
        ylabel('V^C (\muL)')
    else
        ylabel('$\overline{d}$ $ $ ($\mu$m)', 'interpreter','latex')
    end
    xlabel('time (h)');
    set(gca,'FontSize',13,'Fontweight','Bold')
    
end

