close all
addpath(genpath(pwd));
load data_paper.mat
load ICs.mat
modelpath=strcat(cd,'/models/');

IC1=ICs(1,:);
IC2=ICs(2,:);
t1=[0:60:data_paper.Cult1.time(end) data_paper.Cult1.time(end)];t1=unique(t1);
t2=data_paper.Cult2.time';
dc=[19.5849  19.5849 ];
dm=[9.75520  9.95520];

model_lysis_enzyme   =SBmodel(strcat(modelpath,'/Model_mdck_sus_lysis_enzymes.txt'));
model   =SBmodel(strcat(modelpath,'/Model_mdck_sus.txt'));
flag=0;

try % compile the model
    SBPDmakeMEXmodel(model_lysis_enzyme ,'model_lysis_enzyme');
    SBPDmakeMEXmodel(model,'model');
    flag=1;
catch errmsg
    fprintf('\n Mex compilation failed... needs compiler gcc in linux, or MinGW-64 on windows! Using SBsimulate instead \n')
    fprintf('Please wait (non mex simulations may take a while, or it may not work at all)... \n');
end


if flag % simulate mex
    % sim preculture
    results.precult=SBPDsimulate('model',[0 5040],IC1,{ 'd_c','d_m','Elevel' },[dc(1) dm(1) 1],[]);
    
    % update Initial Condition for Cult2
    IC2(12:34)=results.precult.statevalues(end,12:34);
    
    % Normal simulation without taking into account metaolite leak due to cell lysis
    % sim Cult2 before infection 
    results.Cult2=SBPDsimulate('model',[t2(1:6) 48.1667*60],IC2,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1],[]);
    % introduce the virus Cult 2
    results.Cult2.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    temp=SBPDsimulate('model',[results.Cult2.time(end) t2(7:end)],results.Cult2.statevalues(end,:),{ 'd_c','d_m','Elevel' 'kbinf' },[dc(2) dm(2) 1 1],[]);
    % join before and after infection sim data
    results.Cult2.time=[results.Cult2.time(1:end-1) temp.time(2:end)];
    results.Cult2.statevalues=[results.Cult2.statevalues(1:end-1,:);temp.statevalues(2:end,:)*1];
    results.Cult2.variablevalues=[results.Cult2.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)*1];
    
    % taking into account enzyme leak due to cell lysis
    % sim Cult2 before infection 
    IC2(36:41)=1e-12; % add initial conditions for the new states (dead cells)
    results.Cult2_enzymeleak=SBPDsimulate('model_lysis_enzyme',[t2(1:6) 48.1667*60],IC2,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1],[]);
    % introduce the virus Cult 2
    results.Cult2_enzymeleak.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    temp=SBPDsimulate('model_lysis_enzyme',[results.Cult2_enzymeleak.time(end) t2(7:end)],results.Cult2_enzymeleak.statevalues(end,:),{ 'd_c','d_m','Elevel' 'kbinf' },[dc(2) dm(2) 1 1],[]);
    % join before and after infection sim data
    results.Cult2_enzymeleak.time=[results.Cult2_enzymeleak.time(1:end-1) temp.time(2:end)];
    results.Cult2_enzymeleak.statevalues=[results.Cult2_enzymeleak.statevalues(1:end-1,:);temp.statevalues(2:end,:)*1];
    results.Cult2_enzymeleak.variablevalues=[results.Cult2_enzymeleak.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)*1];
else  % simulate without mex
    % sim preculture
    model=SBparameters(model,{ 'd_c','d_m','Elevel' },[dc(1) dm(1) 1]); % update parameters values for d_c d_m and Elevel 
    results.precult=SBsimulate(model,'ode15s',[0 5040],IC1);
    
    % update Initial Condition for Cult2
    IC2(12:34)=results.precult.statevalues(end,12:34);
    
    % Normal simulation without taking into account metaolite leak due to cell lysis
    % sim Cult2 before infection 
    model=SBparameters(model,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1]);% update parameters values for d_c d_m and Elevel 
    results.Cult2=SBsimulate(model,'ode15s',[t2(1:6) 48.1667*60],IC2);
    % introduce the virus Cult 2
    results.Cult2.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    model=SBparameters(model,{ 'kbinf' },[1]);% update parameters values for kbinf
    temp=SBsimulate(model,'ode15s',[results.Cult2.time(end) t2(7:end)],results.Cult2.statevalues(end,:));
    % join before and after infection sim data
    results.Cult2.time=[results.Cult2.time(1:end-1); temp.time(2:end)];
    results.Cult2.statevalues=[results.Cult2.statevalues(1:end-1,:);temp.statevalues(2:end,:)*1];
    results.Cult2.variablevalues=[results.Cult2.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)*1];
    
    % taking into account enzyme leak due to cell lysis
    % sim Cult2 before infection 
    IC2(36:41)=1e-12; % add initial conditions for the new states (dead cells)
    model_lysis_enzyme=SBparameters(model_lysis_enzyme,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1]);% update parameters values for d_c d_m and Elevel 
    results.Cult2_enzymeleak=SBsimulate(model_lysis_enzyme,'ode15s',[t2(1:6) 48.1667*60],IC2);
    % introduce the virus Cult 2
    results.Cult2_enzymeleak.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    model_lysis_enzyme=SBparameters(model_lysis_enzyme,{ 'kbinf' },[1]);% update parameters values for kbinf
    temp=SBsimulate(model_lysis_enzyme,'ode15s',[results.Cult2_enzymeleak.time(end) t2(7:end)],results.Cult2_enzymeleak.statevalues(end,:));
    % join before and after infection sim data
    results.Cult2_enzymeleak.time=[results.Cult2_enzymeleak.time(1:end-1); temp.time(2:end)];
    results.Cult2_enzymeleak.statevalues=[results.Cult2_enzymeleak.statevalues(1:end-1,:);temp.statevalues(2:end,:)*1];
    results.Cult2_enzymeleak.variablevalues=[results.Cult2_enzymeleak.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)*1];

end



hFig = figure;    
set(hFig, 'Color', 'w',...
        'paperpositionmode', 'auto',...
        'paperunits', 'centimeters',...
        'paperposition', [0 0 14.875*0.86 22.2*0.85],...
        'units', 'centimeters',...
        'position', [7 3 27.0875*0.92 8.25*0.84+4.6]);
    
fwidth=22.875*0.85;
fheight=30.2*0.85;
xlabelheight=0.1;
ylabelwidth=1.0;
xspaceheight=0.5*22.2/36;
yspacewidth=0.5*22.2/36;
pheight=(fheight-xlabelheight-5.5*xspaceheight)/6.3;
pwidth=(fwidth-ylabelwidth-yspacewidth*3.2)/3.6;
Pos=[[ylabelwidth+yspacewidth*1.6,xlabelheight+xspaceheight+pheight*1.85,pwidth,pheight];...
[ylabelwidth+yspacewidth*7.2+pwidth,xlabelheight+xspaceheight+pheight*1.85,pwidth,pheight];...
[ylabelwidth+yspacewidth*13+pwidth*2,xlabelheight+xspaceheight+pheight*1.85,pwidth,pheight];...
[ylabelwidth+yspacewidth*1.6,xlabelheight+xspaceheight+pheight*0.25,pwidth,pheight];...
[ylabelwidth+yspacewidth*7.2+pwidth,xlabelheight+xspaceheight+pheight*0.25,pwidth,pheight];...
[ylabelwidth+yspacewidth*13+pwidth*2,xlabelheight+xspaceheight+pheight*0.25,pwidth,pheight]];

states_model={'Glnx' 'NH4x' 'Glux'};le='ABC';
for i=1:3
    position=Pos(i,:);
    hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
    xlim([-10 140])
    ylim([0 1])
    set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);
    hAx1=axes('Parent', hFig,'Color','none');
    hold(hAx1,'on')
    id_model=strcmp(results.Cult2.states,states_model(i));
    id_data=strcmp(data_paper.Cult2.states,states_model(i));
    plot(data_paper.Cult2.time(1:end)/60,data_paper.Cult2.values(1:end,id_data), 'o','LineWidth',2,'MarkerSize',10,'color',[1 0.2 0]);
    plot(results.Cult2.time(1:end)/60,results.Cult2.statevalues(1:end,id_model), '-','LineWidth',2,'MarkerSize',10,'color',[1 0.2 0])
    plot(results.Cult2_enzymeleak.time(1:end)/60,results.Cult2_enzymeleak.statevalues(1:end,id_model), 'b--','LineWidth',2,'MarkerSize',10)
    pl=line([48.1667 48.1667],[0 max(data_paper.Cult2.values(1:end,id_data))*1.3],'LineStyle','-','LineWidth',1.1);
    pl=line([48.1667 48.1667]+12,[0 max(data_paper.Cult2.values(1:end,id_data))*1.3],'LineStyle','-','LineWidth',1.1);
    pl=line([48.1667 48.1667]+24,[0 max(data_paper.Cult2.values(1:end,id_data))*1.3],'LineStyle','-','LineWidth',1.1);
    ylim([0 max(data_paper.Cult2.values(1:end,id_data))*1.25])
    text(105,max(data_paper.Cult2.values(1:end,id_data))*1.24,le(i),'HorizontalAlignment','right','VerticalAlignment','top');
    ylabel([states_model{i}(1:3) '^x' ' (mmol/L)'],'FontSize',11);
%     if i==3;legend('data','enzyme leak(-)','enzyme leak(+)', '0, 12, 24 hpi','Location','eastoutside');end
    set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
    xlabel('time (h)');
    set(gca,'FontSize',12);%,'Fontweight','Bold')
end



position=Pos(4,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
id_model1=strcmp(results.Cult2_enzymeleak.variables,'VdC');
plot(results.Cult2_enzymeleak.time(1:end)/60,results.Cult2_enzymeleak.variablevalues(1:end,id_model1), 'b--','LineWidth',2,'MarkerSize',10)
pl=line([48.1667 48.1667],[0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25],'LineStyle','-','LineWidth',1.1);
pl=line([48.1667 48.1667]+12,[0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25],'LineStyle','-','LineWidth',1.1);
pl=line([48.1667 48.1667]+24,[0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25],'LineStyle','-','LineWidth',1.1);
text(105,max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.23,'D','HorizontalAlignment','right','VerticalAlignment','top');
ylabel( 'V^{dC} (\muL)','FontSize',11);
ylim([0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25])
set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
xlabel('time (h)');
set(gca,'FontSize',12);%,'Fontweight','Bold')


% 
position=Pos(5,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
id_model1=strcmp(results.Cult2.variables,'r_AAex');
plot(results.Cult2.time(1:end)/60,results.Cult2.variablevalues(1:end,id_model1), '-','LineWidth',2,'MarkerSize',10,'color',[1 0.2 0])
pl=line([48.1667 48.1667],[0 max(results.Cult2.variablevalues(1:end,id_model1))*1.17],'LineStyle','-','LineWidth',1.1);
pl=line([48.1667 48.1667]+12,[0 max(results.Cult2.variablevalues(1:end,id_model1))*1.17],'LineStyle','-','LineWidth',1.1);
pl=line([48.1667 48.1667]+24,[0 max(results.Cult2.variablevalues(1:end,id_model1))*1.17],'LineStyle','-','LineWidth',1.1);
text(105,max(results.Cult2.variablevalues(1:end,id_model1))*1.15,'E','HorizontalAlignment','right','VerticalAlignment','top');
ylabel( 'r_{AAex} (mmol/L/min)','FontSize',11);
set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
xlabel('time (h)');
set(gca,'FontSize',12);%,'Fontweight','Bold')

position=Pos(6,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
id_model1=strcmp(results.Cult2_enzymeleak.variables,'rx_AAex');
plot(results.Cult2_enzymeleak.time(1:end)/60,results.Cult2_enzymeleak.variablevalues(1:end,id_model1), 'b--','LineWidth',2,'MarkerSize',10)
pl=line([48.1667 48.1667],[0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25],'LineStyle','-','LineWidth',1.1);
pl=line([48.1667 48.1667]+12,[0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25],'LineStyle','-','LineWidth',1.1);
pl=line([48.1667 48.1667]+24,[0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25],'LineStyle','-','LineWidth',1.1);
text(105,max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.23,'F','HorizontalAlignment','right','VerticalAlignment','top');
ylabel( 'r^x_{AAex} (mmol/L/min)','FontSize',11);
ylim([0 max(results.Cult2_enzymeleak.variablevalues(1:end,id_model1))*1.25])
set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
xlabel('time (h)');
set(gca,'FontSize',12);%,'Fontweight','Bold')



% export_fig C:\enzyme_leak.png -m4 -transparent -q101 -nocrop -a4
