close all
addpath(genpath(pwd));
load data_paper.mat
load ICs.mat
modelpath=strcat(cd,'/models/');

IC1=ICs(1,:);
IC2=ICs(2,:);
t1=[0:60:data_paper.Cult1.time(end) data_paper.Cult1.time(end)];t1=unique(t1);
t2=data_paper.Cult2.time';
dc=[19.5849  19.5849 ];
dm=[9.75520  9.95520];

model_lysis   =SBmodel(strcat(modelpath,'/Model_mdck_sus_lysisleak.txt'));
model   =SBmodel(strcat(modelpath,'/Model_mdck_sus.txt'));
flag=0;
try % compile the model
    SBPDmakeMEXmodel(model_lysis,'model_lysis');
    SBPDmakeMEXmodel(model,'model');
    flag=1;
catch errmsg
    fprintf('\n Mex compilation failed... needs compiler gcc in linux, or MinGW-64 on windows! Using SBsimulate instead \n')
    fprintf('Please wait (non mex simulations may take a while, or it may not work at all)... \n');
end


if flag % simulate mex
    % sim preculture
    results.precult=SBPDsimulate('model',[0 5040],IC1,{ 'd_c','d_m','Elevel' },[dc(1) dm(1) 1],[]);

    % update Initial Condition for Cult2
    IC2(12:34)=results.precult.statevalues(end,12:34);
    
    % Normal simulation without taking into account metaolite leak due to cell lysis
    % sim Cult2 before infection 
    results.Cult2=SBPDsimulate('model',[t2(1:6) 48.1667*60],IC2,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1],[]);
    % introduce the virus Cult 2
    results.Cult2.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    temp=SBPDsimulate('model',[results.Cult2.time(end) t2(7:end)],results.Cult2.statevalues(end,:),{ 'd_c','d_m','Elevel' 'kbinf' },[dc(2) dm(2) 1 1],[]);
    % join before and after infection sim data
    results.Cult2.time=[results.Cult2.time(1:end-1) temp.time(2:end)];
    results.Cult2.statevalues=[results.Cult2.statevalues(1:end-1,:);temp.statevalues(2:end,:)];
    results.Cult2.variablevalues=[results.Cult2.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)];
    
    % taking into account metaolite leak due to cell lysis
    % sim Cult2 before infection 
    results.Cult2_metaleak=SBPDsimulate('model_lysis',[t2(1:6) 48.1667*60],IC2,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1],[]);
    % introduce the virus Cult 2
    results.Cult2_metaleak.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    temp=SBPDsimulate('model_lysis',[results.Cult2_metaleak.time(end) t2(7:end)],results.Cult2_metaleak.statevalues(end,:),{ 'd_c','d_m','Elevel' 'kbinf' },[dc(2) dm(2) 1 1],[]);
    % join before and after infection sim data
    results.Cult2_metaleak.time=[results.Cult2_metaleak.time(1:end-1) temp.time(2:end)];
    results.Cult2_metaleak.statevalues=[results.Cult2_metaleak.statevalues(1:end-1,:);temp.statevalues(2:end,:)];
    results.Cult2_metaleak.variablevalues=[results.Cult2_metaleak.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)];
else % simulate without mex
    % sim preculture
    model=SBparameters(model,{ 'd_c','d_m','Elevel' },[dc(1) dm(1) 1]); % update parameters values for d_c d_m and Elevel 
    results.precult=SBsimulate(model,'ode15s',[0 5040],IC1);

    % update Initial Condition for Cult2
    IC2(12:34)=results.precult.statevalues(end,12:34);
    
    % Normal simulation without taking into account metaolite leak due to cell lysis
    % sim Cult2 before infection 
    model=SBparameters(model,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1]);% update parameters values for d_c d_m and Elevel 
    results.Cult2=SBsimulate(model,'ode15s',[t2(1:6) 48.1667*60],IC2);
    % introduce the virus Cult 2
    results.Cult2.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    model=SBparameters(model,{ 'kbinf' },[1]);% update parameters values for kbinf
    temp=SBsimulate(model,'ode15s',[results.Cult2.time(end) t2(7:end)],results.Cult2.statevalues(end,:));
    % join before and after infection sim data
    results.Cult2.time=[results.Cult2.time(1:end-1); temp.time(2:end)]';
    results.Cult2.statevalues=[results.Cult2.statevalues(1:end-1,:);temp.statevalues(2:end,:)];
    results.Cult2.variablevalues=[results.Cult2.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)];
    
    % taking into account metaolite leak due to cell lysis
    % sim Cult2 before infection 
    model_lysis=SBparameters(model_lysis,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1]);% update parameters values for d_c d_m and Elevel 
    results.Cult2_metaleak=SBsimulate(model_lysis,'ode15s',[t2(1:6) 48.1667*60],IC2);
    % introduce the virus Cult 2
    results.Cult2_metaleak.statevalues(end,35)=1.71e08;
    % sim Cult2 after infection
    model_lysis=SBparameters(model_lysis,{ 'kbinf' },[1]);% update parameters values for kbinf
    temp=SBsimulate(model_lysis,'ode15s',[results.Cult2_metaleak.time(end) t2(7:end)],results.Cult2_metaleak.statevalues(end,:));
    % join before and after infection sim data
    results.Cult2_metaleak.time=[results.Cult2_metaleak.time(1:end-1); temp.time(2:end)]';
    results.Cult2_metaleak.statevalues=[results.Cult2_metaleak.statevalues(1:end-1,:);temp.statevalues(2:end,:)];
    results.Cult2_metaleak.variablevalues=[results.Cult2_metaleak.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)];
end


states_model={'Glcx' 'Lacx'  'Glux' 'Pyrx' 'Glnx' 'NH4x'};
leak_study=zeros(numel(data_paper.Cult2.time(7:end)),6*3);

for i=1:6
    id_model=strcmp(results.Cult1.states,states_model(i));
    ids=(i-1)*3+1:(i-1)*3+3;
    leak_study(:,ids(1))=results.Cult2.statevalues(7:end,id_model);
    leak_study(:,ids(2))=results.Cult2_metaleak.statevalues(7:end,id_model);
    leak_study(:,ids(3))=abs((leak_study(:,ids(2))-leak_study(:,ids(1))))./leak_study(:,ids(1))*100;
end
    
Header=cell(2,6*3);
for i=1:6
    ids=(i-1)*3+1:(i-1)*3+3;
    Header(1,ids)=states_model(i);
    Header(2,ids(1))={'leak (-)'};Header(2,ids(2))={'leak (+)'};Header(2,ids(3))={'diff (%)'};
end

% Table provided in S6 file section 2.1
leak_study=[[{''}; {'Time (h)'}; num2cell(results.Cult2.time(7:end)'/60)] [Header;num2cell(round(leak_study,4,'significant'))]]

