close all
addpath(genpath(pwd));
load data_paper.mat
modelpath=strcat(cd,'/models/');
% 2 cell classes 
model2   =SBmodel(strcat(modelpath,'Model_mdck_sus_c2.txt'));
% 5 cell classes
model5   =SBmodel(strcat(modelpath,'Model_mdck_sus_c5.txt'));
% 7 cell classes
model7   =SBmodel(strcat(modelpath,'Model_mdck_sus_c7.txt'));



flag=0;
try % compile the model
    SBPDmakeMEXmodel(model2,'model2');
    SBPDmakeMEXmodel(model5,'model5');
    SBPDmakeMEXmodel(model7,'model7');
    flag=1;
catch
    fprintf('\n Mex compilation failed... needs compiler gcc in linux, or MinGW-64 on windows! Using SBsimulate instead \n')
    fprintf('Please wait (non mex simulations may take a while, or it may not work at all)... \n');

end

if flag % simulate mex
    results.c2=SBPDsimulate('model2',data_paper.Cult1.time  );
    results.c5=SBPDsimulate('model5',data_paper.Cult1.time  );
    results.c7=SBPDsimulate('model7',data_paper.Cult1.time );
else % simulate without mex
    results.c2=SBsimulate(model2,'ode15s',data_paper.Cult1.time);
    results.c5=SBsimulate(model5,'ode15s',data_paper.Cult1.time);
    results.c7=SBsimulate(model7,'ode15s',data_paper.Cult1.time);
end


%%% plot results and objective function values %%%

hFig = figure;    
set(hFig, 'Color', 'w',...
        'paperpositionmode', 'auto',...
        'paperunits', 'centimeters',...
        'paperposition', [0 0 14.875*0.86 22.2*0.85],...
        'units', 'centimeters',...
        'position', [7 3 29.5875*0.92 7.25*0.84+4.6]);
    
fwidth=22.875*0.85;
fheight=30.2*0.85;
xlabelheight=0.1;
ylabelwidth=1.0;
xspaceheight=0.5*22.2/36;
yspacewidth=0.5*22.2/36;
pheight=(fheight-xlabelheight-5.5*xspaceheight)/6.3;
pwidth=(fwidth-ylabelwidth-yspacewidth*3.2)/3.6;
Pos1=[[ylabelwidth+yspacewidth*1.6,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];
Pos2=[[ylabelwidth+yspacewidth*7.2+pwidth,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];
Pos3=[[ylabelwidth+yspacewidth*13+pwidth*2,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];
Pos4=[[ylabelwidth+yspacewidth*17.8+pwidth*3.2,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];


position=Pos1(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);v=0.15;
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables={'X_tot'};plot(data_paper.Cult1.time(1:end-1)/60,data_paper.Cult1.values(1:end-1,1)*1e6,'ks','MarkerFaceColor','k','MarkerSize',4,'LineWidth',2);hold on;
plot(results.c2.time/60,results.c2.variablevalues(:,strcmp(results.c2.variables,variables)),'b--','LineWidth',2);hold on;
plot(results.c5.time/60,results.c5.variablevalues(:,strcmp(results.c5.variables,variables)),'g--','LineWidth',2);hold on;
plot(results.c7.time/60,results.c7.variablevalues(:,strcmp(results.c7.variables,variables)),'c--','LineWidth',2);hold on;
% xlabel('time (h)');legend('data','N^c=2','N^c=5','N^c=7','Location','southoutside');
text(188,max([results.c7.variablevalues(:,strcmp(results.c7.variables,variables))])*1.15,'A','HorizontalAlignment','right','VerticalAlignment','top');
ylabel('X_v (Cells/mL)','FontSize',11);
set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
%set(gca,'Fontweight','Bold')

position=Pos2(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);v=0.15;
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables={'d'};plot(data_paper.Cult1.time(1:end-1)/60,data_paper.Cult1.values(1:end-1,3),'ks','MarkerFaceColor','k','MarkerSize',4,'LineWidth',2);hold on;
plot(results.c2.time/60,results.c2.variablevalues(:,strcmp(results.c2.variables,variables)),'b--','LineWidth',2);hold on;
plot(results.c5.time/60,results.c5.variablevalues(:,strcmp(results.c5.variables,variables)),'g--','LineWidth',2);hold on;
plot(results.c7.time/60,results.c7.variablevalues(:,strcmp(results.c7.variables,variables)),'c--','LineWidth',2);hold on;
text(188,16.9*1.025,'B','HorizontalAlignment','right','VerticalAlignment','top');
ylabel('$\overline{d}$ $ $ ($\mu$m)', 'interpreter','latex','FontSize',11,'Fontweight','Bold');ylim([9 17.4]);
xlabel('time (h)');
set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
%set(gca,'Fontweight','Bold')

position=Pos3(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);v=0.15;
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables='VCS';
plot(results.c2.time/60,results.c2.variablevalues(:,strcmp(results.c2.variables,variables)),'b--','LineWidth',2);hold on;
plot(results.c5.time/60,results.c5.variablevalues(:,strcmp(results.c5.variables,variables)),'g--','LineWidth',2);hold on;
plot(results.c7.time/60,results.c7.variablevalues(:,strcmp(results.c7.variables,variables)),'c--','LineWidth',2);hold on;
xlabel('time (h)');ylabel( ['V^c_{s}' ' (L/cell)'])
text(188,max([results.c7.variablevalues(:,strcmp(results.c7.variables,variables))])*0.985,'C','HorizontalAlignment','right','VerticalAlignment','top');

set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
%set(gca,'Fontweight','Bold')

position=Pos4(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);v=0.15;
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables='Kmax_HK';
plot(results.c2.time/60,results.c2.variablevalues(:,strcmp(results.c2.variables,variables)),'b--','LineWidth',2);hold on;
plot(results.c5.time/60,results.c5.variablevalues(:,strcmp(results.c5.variables,variables)),'g--','LineWidth',2);hold on;
plot(results.c7.time/60,results.c7.variablevalues(:,strcmp(results.c7.variables,variables)),'c--','LineWidth',2);hold on;
xticks(0:48:200);xlabel('time (h)');ylabel('K^{max}_{HK}  (mmol/L/min)')
text(188,max([results.c7.variablevalues(:,strcmp(results.c7.variables,variables))])*1.01,'D','HorizontalAlignment','right','VerticalAlignment','top');

set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');
%set(gca,'Fontweight','Bold')


J=zeros(3,2);
xv=data_paper.Cult1.values(:,1)*1e6;dm=data_paper.Cult1.values(:,3);

J(1,1)=sum(((results.c2.variablevalues(:,1)-xv)./max(xv)).^2);
J(1,2)=sum(((results.c2.variablevalues(:,strcmp(results.c2.variables,'d'))-dm)./max(dm)).^2);

J(2,1)=sum(((results.c5.variablevalues(:,1)-xv)./max(xv)).^2);
J(2,2)=sum(((results.c5.variablevalues(:,strcmp(results.c5.variables,'d'))-dm)./max(dm)).^2);

J(3,1)=sum(((results.c7.variablevalues(:,1)-xv)./max(xv)).^2);
J(3,2)=sum(((results.c7.variablevalues(:,strcmp(results.c7.variables,'d'))-dm)./max(dm)).^2);

J_sum=sum(J,2)
J

% export_fig C:\classes_impact.png -m4 -transparent -q101 -nocrop -a4
