function [datawide] = SBPOPdataset2wide(data,paramnames,paramvalues)
% [DESCRIPTION]
% This function expands a dataset from a row based format to a column based 
% format. Records in the row based format are stored in rows, while a parameter
% column defines the type/name of the recorded parameter. In the column  based 
% format there is a column for each measured parameter with the column name as
% the parameters name. 
% The name of the columns with the parameternames and values need to be provided.
% All other columns are kept. An ID and a TIME column needs to be present, since
% all parameters for a single ID at a single TIME point are converted into one row
% of the wide dataset.
%
% [SYNTAX]
% datawide = SBPOPdataset2wide(data,paramnames,paramvalues)
%
% [INPUT]
% data:         dataset in row format
% paramnames:   string: name of the column in which the parameter names are recorded
% paramvalues:  string: name of the column in which the parameter values are recorded
%
% [OUTPUT]
% datawide:     dataset in wide format (one column per parameter)
%
% [ASSUMPTIONS]
% ID and TIME columns are present. Grouping done by ID and TIME.
%
% [AUTHOR]
% Henning Schmidt, henning.schmidt@novartis.com
%
% [DATE]
% 13.12.2010
%
% [PLATFORM]
% Windows XP Engine, MATLAB R2009a, MODESIM MATLAB
%
% [KEYWORDS]
% dataset, row, column
% 
% [TOOLBOXES USED]
% Statistics toolbox
%
% [VALIDATION HISTORY]
%
% [MODIFICATION HISTORY]

% Information:
% ============
% Copyright  2012 Novartis Pharma AG
% 
% This program is Free Open Source Software: you can redistribute it and/or modify 
% it under the terms of the GNU General Public License as published by 
% the Free Software Foundation, either version 3 of the License, or 
% (at your option) any later version. 
% 
% This program is distributed in the hope that it will be useful, 
% but WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
% GNU General Public License for more details. 
% 
% You should have received a copy of the GNU General Public License 
% along with this program. If not, see <http://www.gnu.org/licenses/>.


% Get all column names which are not parameters or values
cnames = get(data,'VarNames');
cnames(strmatchSB(paramnames,cnames)) = [];
cnames(strmatchSB(paramvalues,cnames)) = [];

% Bing into column based (wide) format
datawide = dataset();
PARAM = eval(sprintf('unique(data.%s);',paramnames));

allID = unique(data.ID);
for k=1:length(allID),
    datak = data(data.ID==allID(k),:);
    allTIME = unique(datak.TIME);
    for k2=1:length(allTIME),
        datakk2 = datak(datak.TIME==allTIME(k2),:);
        % Create row
        row = dataset();
        for k3=1:length(cnames),
            eval(['row.' cnames{k3} ' = datakk2.' cnames{k3} '(1);']);
        end
        for k3=1:length(PARAM),
            ix = strmatchSB(PARAM{k3},eval(['datakk2.' paramnames]),'exact');
            if isempty(ix),
                eval(sprintf('row.%s = NaN;',PARAM{k3}));
            else
                eval(['row.' PARAM{k3} ' = datakk2.' paramvalues '(ix);']);
            end
        end
        datawide = [datawide; row];
    end
end




