function [names,formulas,arguments] = SBfunctions(model)
% SBfunctions: Returns information about the functions in an SBmodel.
%
% USAGE:
% ======
% [names,formulas,arguments] = SBfunctions(model)
%
% model: SBmodel (function can not be used on M-file model)
%
% Output Arguments:
% =================
% names: cell-array with models function names
% formulas: cell-array with formuas for the functions
% arguments: cell-array with arguments for the functions

% Information:
% ============
% Copyright (C) 2005-2007 Fraunhofer Chalmers Centre, Gothenburg, Sweden
% Main author: Henning Schmidt
% 
% Changes for the SBTOOLBOX2:
% 1/1/2008  Henning Schmidt, henning@sbtoolbox2.org
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  
% USA.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PROCESS SBMODEL OR ODE FILE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strcmp('SBmodel',class(model)),
    sbm = SBstruct(model);
    if ~isempty(sbm.functions),
        names = {sbm.functions.name};
        formulas = {sbm.functions.formula};
        arguments = {sbm.functions.arguments};
    else
        names = {};
        formulas = {};
        arguments = {};
    end
else
    error('The function can only be used on SBmodels, not on M-file ODE models');
end
names = names(:);
formulas = formulas(:);
arguments = arguments(:);
return