close all
addpath(genpath(pwd));
load data_paper.mat
load ICs.mat
dc=[19.5849  19.5849 ];
dm=[9.75520  9.95520];
modelpath=strcat(cd,'/models/');

model_tstep   =SBmodel(strcat(modelpath,'Model_mdck_sus_c5.txt'));
model_notstep   =SBmodel(strcat(modelpath,'Model_mdck_sus_nostep.txt'));
flag=0;
try % compile the model
    SBPDmakeMEXmodel(model_tstep,'model_tstep');
    SBPDmakeMEXmodel(model_notstep,'model_notstep');
    flag=1;
catch
    fprintf('\n Mex compilation failed... needs compiler gcc in linux, or MinGW-64 on windows! Using SBsimulate instead \n')
    fprintf('Please wait (non mex simulations may take a while, or it may not work at all)... \n');
end

if flag % simulate mex
    % simulate model with step function
    results.tstep=SBPDsimulate('model_tstep',[data_paper.Cult2.time(1:6); 48.1667*60],[ICs(2,1:6) 0 0],{ 'd_c','d_m','Elevel'},[dc(2) dm(2) 1]);
    results.tstep.statevalues(end,end-1)=1.71e08; % introduce virus
    temp=SBPDsimulate('model_tstep',[results.tstep.time(end);data_paper.Cult2.time(7:end)],results.tstep.statevalues(end,:),{ 'd_c','d_m','Elevel','kbinf'},[ dc(2) dm(2) 1 1]);
    results.tstep.time=[results.tstep.time(1:end-1); temp.time(2:end)];
    results.tstep.statevalues=[results.tstep.statevalues(1:end-1,:);temp.statevalues(2:end,:)*1];
    results.tstep.variablevalues=[results.tstep.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)*1];
    % simulate model without step function
    results.notstep=SBPDsimulate('model_notstep',[data_paper.Cult2.time(1:6); 48.1667*60],[ICs(2,1:6) 0 0],{ 'd_c','d_m','Elevel'},[dc(2) dm(2) 1]);
    results.notstep.statevalues(end,end-1)=1.71e08;% introduce virus
    temp=SBPDsimulate('model_notstep',[results.notstep.time(end); data_paper.Cult2.time(7:end)],results.notstep.statevalues(end,:),[{ 'd_c','d_m','Elevel','kbinf'}],[ dc(2) dm(2) 1 1]);
    % join before and after infection sim data
    results.notstep.time=[results.notstep.time(1:end-1); temp.time(2:end)];
    results.notstep.statevalues=[results.notstep.statevalues(1:end-1,:);temp.statevalues(2:end,:)];
    results.notstep.variablevalues=[results.notstep.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)];
else % simulate without mex
    % simulate model with step function
    model_tstep=SBparameters(model_tstep,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1]); % update parameters values for d_c d_m and Elevel 
    results.tstep=SBsimulate(model_tstep,'ode15s',[data_paper.Cult2.time(1:6); 48.1667*60],[ICs(2,1:6) 0 0]);
    results.tstep.statevalues(end,end-1)=1.71e08; % introduce virus
    model_tstep=SBparameters(model_tstep,{ 'kbinf' },[1]);% update parameters values for kbinf
    temp=SBsimulate(model_tstep,'ode15s',[results.tstep.time(end);data_paper.Cult2.time(7:end)],results.tstep.statevalues(end,:));
    results.tstep.time=[results.tstep.time(1:end-1); temp.time(2:end)];
    results.tstep.statevalues=[results.tstep.statevalues(1:end-1,:);temp.statevalues(2:end,:)*1];
    results.tstep.variablevalues=[results.tstep.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)*1];
    % simulate model without step function
    model_notstep=SBparameters(model_notstep,{ 'd_c','d_m','Elevel' },[dc(2) dm(2) 1]); % update parameters values for d_c d_m and Elevel 
    results.notstep=SBsimulate(model_notstep,'ode15s',[data_paper.Cult2.time(1:6); 48.1667*60],[ICs(2,1:6) 0 0]);
    results.notstep.statevalues(end,end-1)=1.71e08;% introduce virus
    model_notstep=SBparameters(model_notstep,{ 'kbinf' },[1]);% update parameters values for kbinf
    temp=SBsimulate(model_notstep,'ode15s',[results.notstep.time(end); data_paper.Cult2.time(7:end)],results.notstep.statevalues(end,:));
    % join before and after infection sim data
    results.notstep.time=[results.notstep.time(1:end-1); temp.time(2:end)];
    results.notstep.statevalues=[results.notstep.statevalues(1:end-1,:);temp.statevalues(2:end,:)];
    results.notstep.variablevalues=[results.notstep.variablevalues(1:end-1,:);temp.variablevalues(2:end,:)];
end


hFig = figure;    
set(hFig, 'Color', 'w',...
        'paperpositionmode', 'auto',...
        'paperunits', 'centimeters',...
        'paperposition', [0 0 14.875*0.86 22.2*0.85],...
        'units', 'centimeters',...
        'position', [7 3 30.5875*0.92 7.25*0.84+4.6]);
    
fwidth=22.875*0.85;
fheight=30.2*0.85;
xlabelheight=0.1;
ylabelwidth=1.0;
xspaceheight=0.5*22.2/36;
yspacewidth=0.5*22.2/36;
pheight=(fheight-xlabelheight-5.5*xspaceheight)/6.3;
pwidth=(fwidth-ylabelwidth-yspacewidth*3.2)/3.6;
Pos1=[[ylabelwidth+yspacewidth*1.6,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];
Pos2=[[ylabelwidth+yspacewidth*7.2+pwidth,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];
Pos3=[[ylabelwidth+yspacewidth*13+pwidth*2,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];
Pos4=[[ylabelwidth+yspacewidth*17.8+pwidth*3.2,xlabelheight+xspaceheight+pheight*1.15,pwidth,pheight]];


position=Pos1(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables={'X_tot'};plot(data_paper.Cult2.time(1:end-1)/60,data_paper.Cult2.values(1:end-1,1)*1e6,'ks','MarkerFaceColor','k','MarkerSize',7,'LineWidth',2);hold on;
plot(results.notstep.time/60,results.notstep.variablevalues(:,strcmp(results.notstep.variables,variables)),'b--','LineWidth',2);hold on;
plot(results.tstep.time/60,results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables)),'g--','LineWidth',2);hold on;
xlabel('time (h)');%xlim([0 160])
pl=line([48.1667 48.1667],[0 max([results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables))])*1.17],'LineStyle','-','LineWidth',1.1);
text(105,max([results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables))])*1.15,'A','HorizontalAlignment','right','VerticalAlignment','top');
ylabel('X_v (Cells/mL)','FontSize',11);
set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');


position=Pos2(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);v=0.15;
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables={'d'};plot(data_paper.Cult2.time(1:end-1)/60,data_paper.Cult2.values(1:end-1,3),'ks','MarkerFaceColor','k','MarkerSize',7,'LineWidth',2);hold on;
plot(results.notstep.time/60,results.notstep.variablevalues(:,strcmp(results.notstep.variables,variables)),'b--','LineWidth',2);hold on;
plot(results.tstep.time/60,results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables)),'g--','LineWidth',2);hold on;
text(105,16.9*1.025,'B','HorizontalAlignment','right','VerticalAlignment','top');
ylabel('$\overline{d}$ $ $ ($\mu$m)', 'interpreter','latex','FontSize',11);ylim([9 17.4]);
xlabel('time (h)');pl=line([48.1667 48.1667],[0 16.9*1.025],'LineStyle','-','LineWidth',1.1);
% legend('data','without step function','with step function', 'time of infection','Location','southoutside');%xlim([0 160]);

set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');


position=Pos3(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);v=0.15;
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables='VCS';
plot(results.notstep.time/60,results.notstep.variablevalues(:,strcmp(results.notstep.variables,variables)),'b--','LineWidth',3);hold on;
plot(results.tstep.time/60,results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables)),'g--','LineWidth',3);hold on;
xlabel('time (h)');
pl=line([48.1667 48.1667],[0 max([results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables))])*1.35],'LineStyle','-','LineWidth',1.1);
ylabel( ['V^c_{s}' ' (L/cell)'])
text(105,max([results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables))])*1.35,'C','HorizontalAlignment','right','VerticalAlignment','top');
set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');

position=Pos4(1,:);
hAx1t=axes('Parent', hFig,'XColor',[1 1 1],'YColor',[1 1 1 ]);
xlim([-10 200])
ylim([0 1])
set(hAx1t,'Units','centimeters','position',position,'YTickLabel',[],'XTickLabel',[]);v=0.15;
hAx1=axes('Parent', hFig,'Color','none');
hold(hAx1,'on')
variables='Kmax_HK';
plot(results.notstep.time/60,results.notstep.variablevalues(:,strcmp(results.notstep.variables,variables)),'b--','LineWidth',3);hold on;
plot(results.tstep.time/60,results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables)),'g--','LineWidth',3);hold on;
xlabel('time (h)');
pl=line([48.1667 48.1667],[0 max([results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables))])*1.4],'LineStyle','-','LineWidth',1.1);
ylabel('K^{max}_{HK}  (mmol/L/min)')
text(105,max([results.tstep.variablevalues(:,strcmp(results.tstep.variables,variables))])*1.4,'D','HorizontalAlignment','right','VerticalAlignment','top');

set(hAx1,'Units','centimeters','position',position,'XTick',[0:48:200],'XTickLabel',[0:48:200],'Box','on','XGrid','on','YMinorGrid','on','GridAlpha',0.4,'MinorGridAlpha',0.5,'FontSize',10,'FontName','Arial');

J=zeros(2,2);
xv=data_paper.Cult2.values(:,1)*1e6;dm=data_paper.Cult2.values(:,3);

J(1,1)=sum(((results.notstep.variablevalues(:,1)-xv)./max(xv)).^2);
J(1,2)=sum(((results.notstep.variablevalues(:,strcmp(results.notstep.variables,'d'))-dm)./max(dm)).^2);

J(2,1)=sum(((results.tstep.variablevalues(:,1)-xv)./max(xv)).^2);
J(2,2)=sum(((results.tstep.variablevalues(:,strcmp(results.tstep.variables,'d'))-dm)./max(dm)).^2);

% Table provided in S1 file section 3.2
J_sum=sum(J,2)
J

% export_fig C:\cell_timestep.png -m4 -transparent -q101 -nocrop -a4
